@@ -3,7 +3,7 @@ package Games::Framework::RCP::Database::Result::Callscript;
 use strict;
 use warnings;
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 use base qw/DBIx::Class/;
 
@@ -51,11 +51,11 @@ __END__
 
 =head1 NAME
 
-Games::Framework::RCP::Database::Result::Callscript
+Games::Framework::RCP::Database::Result::Callscript - Listing of which characters are in a callscript: think grab bag.
 
 =head1 VERSION
 
-0.21
+0.22
 
 =head1 DESCRIPTION
 
