@@ -3,7 +3,7 @@ package Games::Framework::RCP::Database::Result::ClassMove;
 use strict;
 use warnings;
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 use base qw/DBIx::Class/;
 
@@ -57,11 +57,11 @@ __END__
 
 =head1 NAME
 
-Games::Framework::RCP::Database::Result::ClassMove
+Games::Framework::RCP::Database::Result::ClassMove - The moves each class has, along with how much to buy.
 
 =head1 VERSION
 
-0.21
+0.22
 
 =head1 DESCRIPTION
 
