@@ -3,7 +3,7 @@ package Games::Framework::RCP::Database::Result::ItemStat;
 use strict;
 use warnings;
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 use base qw/DBIx::Class/;
 
@@ -51,11 +51,11 @@ __END__
 
 =head1 NAME
 
-Games::Framework::RCP::Database::Result::ItemStat
+Games::Framework::RCP::Database::Result::ItemStat - The list of the various stats that items can modify when used.
 
 =head1 VERSION
 
-0.21
+0.22
 
 =head1 DESCRIPTION
 
