@@ -3,7 +3,7 @@ package Games::Framework::RCP::Database::Result::ItemUsage;
 use strict;
 use warnings;
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 use base qw/DBIx::Class/;
 
@@ -58,11 +58,11 @@ __END__
 
 =head1 NAME
 
-Games::Framework::RCP::Database::Result::ItemUsage
+Games::Framework::RCP::Database::Result::ItemUsage - The list of the various item usages.
 
 =head1 VERSION
 
-0.21
+0.22
 
 =head1 DESCRIPTION
 
