@@ -3,7 +3,7 @@ package Games::Framework::RCP::Database::Result::Move;
 use strict;
 use warnings;
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 use base qw/DBIx::Class/;
 
@@ -89,11 +89,11 @@ __END__
 
 =head1 NAME
 
-Games::Framework::RCP::Database::Result::Move
+Games::Framework::RCP::Database::Result::Move - Every single move available in the game.
 
 =head1 VERSION
 
-0.21
+0.22
 
 =head1 DESCRIPTION
 
