@@ -3,7 +3,7 @@ package Games::Framework::RCP::Database::Result::PlayerChar;
 use strict;
 use warnings;
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 use base qw/DBIx::Class/;
 
@@ -41,11 +41,11 @@ __END__
 
 =head1 NAME
 
-Games::Framework::RCP::Database::Result::PlayerChar
+Games::Framework::RCP::Database::Result::PlayerChar - The list of every character with a real player behind the screen.
 
 =head1 VERSION
 
-0.21
+0.22
 
 =head1 DESCRIPTION
 
