@@ -3,7 +3,7 @@ package Games::Framework::RCP::Database::Result::VarStr;
 use strict;
 use warnings;
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 use base qw/DBIx::Class/;
 
@@ -49,11 +49,11 @@ __END__
 
 =head1 NAME
 
-Games::Framework::RCP::Database::Result::VarStr
+Games::Framework::RCP::Database::Result::VarStr - List of string variables.
 
 =head1 VERSION
 
-0.21
+0.22
 
 =head1 DESCRIPTION
 
